@@ -15,6 +15,18 @@ from vulture.config import make_config
 DEFAULT_CONFIDENCE = 60
 
 IGNORED_VARIABLE_NAMES = {"object", "self"}
+PYTEST_FUNCTION_NAMES = {
+    "setup_module",
+    "teardown_module",
+    "setup_function",
+    "teardown_function",
+}
+PYTEST_METHOD_NAMES = {
+    "setup_class",
+    "teardown_class",
+    "setup_method",
+    "teardown_method",
+}
 
 ERROR_CODES = {
     "attribute": "V101",
@@ -53,6 +65,15 @@ def _is_test_file(filename):
     )
 
 
+def _assigns_special_variable__all__(node):
+    assert isinstance(node, ast.Assign)
+    return isinstance(node.value, (ast.List, ast.Tuple)) and any(
+        target.id == "__all__"
+        for target in node.targets
+        if isinstance(target, ast.Name)
+    )
+
+
 def _ignore_class(filename, class_name):
     return _is_test_file(filename) and "Test" in class_name
 
@@ -67,12 +88,16 @@ def _ignore_import(filename, import_name):
 
 
 def _ignore_function(filename, function_name):
-    return function_name.startswith("test_") and _is_test_file(filename)
+    return (
+        function_name in PYTEST_FUNCTION_NAMES
+        or function_name.startswith("test_")
+    ) and _is_test_file(filename)
 
 
 def _ignore_method(filename, method_name):
     return _is_special_name(method_name) or (
-        method_name.startswith("test_") and _is_test_file(filename)
+        (method_name in PYTEST_METHOD_NAMES or method_name.startswith("test_"))
+        and _is_test_file(filename)
     )
 
 
@@ -609,16 +634,27 @@ class Vulture(ast.NodeVisitor):
 
     def visit_Name(self, node):
         if (
-            isinstance(node.ctx, ast.Load)
+            isinstance(node.ctx, (ast.Load, ast.Del))
             and node.id not in IGNORED_VARIABLE_NAMES
         ):
             self.used_names.add(node.id)
         elif isinstance(node.ctx, (ast.Param, ast.Store)):
             self._define_variable(node.id, node)
 
+    def visit_Assign(self, node):
+        if _assigns_special_variable__all__(node):
+            assert isinstance(node.value, (ast.List, ast.Tuple))
+            for elt in node.value.elts:
+                if isinstance(elt, ast.Str):
+                    self.used_names.add(elt.s)
+
     def visit_While(self, node):
         self._handle_conditional_node(node, "while")
 
+    def visit_MatchClass(self, node):
+        for kwd_attr in node.kwd_attrs:
+            self.used_names.add(kwd_attr)
+
     def visit(self, node):
         method = "visit_" + node.__class__.__name__
         visitor = getattr(self, method, None)
